@@ -1,5 +1,6 @@
 import os
 import time
+import click
 import json
 from contextlib import contextmanager
 
@@ -9,7 +10,7 @@ def jsondb(path):
     """
     Edit a given dictionary and it will be persisted on exit.
     """
-    d = {"timeline": [], "summary": {}}
+    d = {"timeline": []}
     if os.path.exists(path):
         with open(path, "r") as fl:
             d = json.loads(fl.read())
@@ -40,40 +41,48 @@ def to_jira(total):
     return val.strip()
 
 
-def run(args):
-    if args.f != "summary":
-        assert args.s is not None
+@click.command(name="python -m worktimething")
+@click.argument("cmd", default="summary")
+@click.argument("slug", default="")
+@click.option("--json-path", default="db.json", help="Where to store data?")
+def run(cmd, slug, json_path):
+    if cmd != "summary":
+        assert slug is not None
 
     def begin():
-        with jsondb(args.json_path) as db:
+        with jsondb(json_path) as db:
             if db["timeline"]:
                 last_time, last_slug, last_act = db["timeline"][-1]
-                if last_slug != args.s and last_act == "begin":
+                if last_slug != slug and last_act == "begin":
                     db["timeline"].append((time.time(), last_slug, "end"))
-            db["timeline"].append((time.time(), args.s, "begin"))
+                if last_slug == slug and last_act == "begin":
+                    print("This task is currently running")
+                    return
+            db["timeline"].append((time.time(), slug, "begin"))
 
     def end():
-        with jsondb(args.json_path) as db:
+        with jsondb(json_path) as db:
             if db["timeline"]:
                 last_time, last_slug, last_act = db["timeline"][-1]
-                assert last_slug == args.s and last_act == "begin"
-            db["timeline"].append((time.time(), args.s, "end"))
+                assert last_slug == slug and last_act == "begin"
+            db["timeline"].append((time.time(), slug, "end"))
 
     def summary():
-        with jsondb(args.json_path) as db:
+        with jsondb(json_path) as db:
             last_slug = None
             started_at = None
             totals = {
                 slug: {"total": 0, "started_at": None, "running": False}
                 for _, slug, _ in db["timeline"]
             }
+            total_time = 0
             for slug, data in totals.items():
                 for stamp, _, act in (x for x in db["timeline"] if x[1] == slug):
                     if act == "begin":
                         data["started_at"] = stamp
                         data["running"] = True
                     elif act == "end":
-                        data["total"] += time.time() - data["started_at"]
+                        data["total"] += stamp - data["started_at"]
                         data["started_at"] = None
                         data["running"] = False
                 prefix = "*" if data["running"] else " "
@@ -82,11 +91,14 @@ def run(args):
                     if data["running"]
                     else data["total"]
                 )
+                total_time += total
 
-                print(f"{slug:>20} : {prefix} {to_jira(total)}")
+                print(f"{slug:>5} : {prefix} {to_jira(total)}")
+            print("-" * 20)
+            print(f"{'TOTAL':>5} :   {to_jira(total_time)}")
 
     b = start = begin
     e = stop = end
-    exec(f"{args.f}()")
-    if args.f != "summary":
+    exec(f"{cmd}()")
+    if cmd != "summary":
         print(summary())
